! $Id: synthesizing.prg,v 1.2 1999/09/23 16:58:29 cguirao Exp $
! $Name: FIASCO-1_1 $ 
!
! AUTHOR: C.Guirao
! NAME: synthesizing.prg: 
!  Creates a synthetic solar spectrum using the SPECTRUM and SMOOTH
!  programs from Richard O. Gray. Plots the result synthetic spectrum
!  using MIDAS
!  Commands 'spectrum' and 'smooth' are expected to be located in $PATH
! 
! USAGE: @@ synthesizing 
! EXAMPLES:
!*******************************************************************************
! ECHO/FULL
!
! INPUT PARAMS:
! p1 REQUIRED: FITS image to be converted
! p2 REQUIRED: Ouput BDF image
! p3 REQUIRED: Wavelength range to be calculated
! p4 REQUIRED: Ouput resolution
! p5 REQUIRED: Ouput step
! p6 OPTIONAL: graph_id
!
! Edit here to change defaults:
!
 DEFINE/PARA p1 ? I "Enter input ASCII file (from SPECTRUM, e.g. sun.mod) ? "
 DEFINE/PARA p2 ? I "Enter ouput ASCII file ? "
 DEFINE/PARA p3 ? NUM "Enter wavelength range ? "
 DEFINE/PARA p4 ? NUM "Enter output resolution ? "
 DEFINE/PARA p5 ? NUM "Enter output step ? "
 DEFINE/PARA p6 0 NUM "Graphical ID"
!
! Convert paramaters into variables:
!
 DEFINE/LOCA cmd/c/1/20  "synthesizing"
 DEFINE/LOCA input/c/1/40 	{p1}
 DEFINE/LOCA output/c/1/40	{p2}
 DEFINE/LOCA wave_range/r/1/2   {p3}
 DEFINE/LOCA resolution/r/1/1   {p4}
 DEFINE/LOCA step/r/1/1   	{p5}
 DEFINE/LOCA graph_id/r/1/1   	{p6}
!
! Expecting the script synthesizing.sh to be in $HOME/midwork.
! The commands 'spectrum' and 'smooth' are expected to be installed from
! package SPECTRUM
!
 $rm -f {output}
 $./synthesizing.sh {input} {output} {wave_range(1)} {wave_range(2)} {resolution} {step}
 IF m$exist(output) .eq. 0 THEN
   WRITE/OUT ASCII TABLE {output} not generated
   RETURN/EXIT
 ENDIF
!
 WRITE/OUT ASCII TABLE {output} generated
 $rm -rf sun.fmt
 $echo DEFINE/FIELD 1 9 R F15.3 :WAVE ANGSTROMS > sun.fmt 
 $echo DEFINE/FIELD 10 20 R F15.6 :FLUX INTENSITY >> sun.fmt
!
 WRITE/OUT ASCII TABLE {output} converted to MIDAS {output}.tbl
 CREATE/TABL {output} 2 100 {output} sun.fmt
!
 WRITE/OUT MIDAS {output}.tbl converted to FITS {output}.tfit
 OUTDISK/FITS {output}.tbl {output}.tfit >NULL
!
 WRITE/OUT MIDAS {output}.tbl converted to IMAGE {output}.bdf
 COPY/TI {output}.tbl {output}.bdf :FLUX
 WRITE/DESC  {output}.bdf STEP/D/1/1 {step}
 WRITE/DESC  {output}.bdf START/D/1/1 {wave_range(1)} 
!
 WRITE/OUT MIDAS {output}.bdf converted to FITS {output}.fit
 OUTDISK/FITS {output}.bdf {output}.fit >NULL
!
 CREATE/GRAP {graph_id} >NULL
 ASSIGN/GRAP G,{graph_id}
! SET/GRAP pm=1 font=0 stype=0 colour=1
 SET/GRAP pm=1 stype=0 colour=1
 WRITE/OUT PLOT/TABL {output} :WAVE :FLUX
 PLOT/TABL {output} :WAVE :FLUX
!
! Cleaning temporary files
!
! WRITE/OUT {cmd}: Removing temporary files
 $rm -f NULL *rst intermediate sun.fmt FORGRdrs.KEY
!
 ECHO/OFF
